@@ -423,6 +423,7 @@ setClass("BIOMOD.Model.Options",
                    
                    GAM = list( algo = "GAM_mgcv",
                                type = "s_smoother",
+                               k = NULL,
                                interaction.level = 0,
                                myFormula = NULL,
                                family = 'binomial',
@@ -500,9 +501,10 @@ setMethod('show', signature('BIOMOD.Model.Options'),
             cat("\n")
             cat("\nGAM = list( algo = '", object@GAM$algo, "',", sep="")
             cat("\n            type = '", object@GAM$type, "',", sep="")
+            cat("\n            k = ", ifelse(length(object@GAM$k) < 1,'NULL',object@GAM$k), ",", sep="")
             cat("\n            interaction.level = ", object@GAM$interaction.level, ",", sep="")
             cat("\n            myFormula = ", ifelse(length(object@GAM$myFormula) < 1,'NULL',paste(object@GAM$myFormula[2],object@GAM$myFormula[1],object@GAM$myFormula[3])), ",", sep="")
-            cat("\n            family = ", object@GAM$family, ",", sep="")
+            cat("\n            family = '", object@GAM$family, "',", sep="")
             cat("\n            control = gam.control(", .print.control(object@GAM$control), ") ),", sep="", fill=.Options$width)
 
             ## CTA options
